@@ -1,4 +1,4 @@
-/*	$Id: lowdown.h,v 1.107 2021/07/09 08:46:52 kristaps Exp $ */
+/*	$Id$ */
 /*
  * Copyright (c) 2017--2021 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -124,7 +124,9 @@ enum	hlist_fl {
 	HLIST_FL_ORDERED = (1 << 0), /* <ol> list item */
 	HLIST_FL_BLOCK = (1 << 1), /* <li> containing block data */
 	HLIST_FL_UNORDERED = (1 << 2), /* <ul> list item */
-	HLIST_FL_DEF = (1 << 3) /* <dl> list item */
+	HLIST_FL_DEF = (1 << 3), /* <dl> list item */
+	HLIST_FL_CHECKED = (1 << 4), /* <li> with checked box */
+	HLIST_FL_UNCHECKED = (1 << 5), /* <li> with unchecked box */
 };
 
 /*
@@ -164,7 +166,6 @@ struct	rndr_entity {
 
 struct	rndr_autolink {
 	struct lowdown_buf link; /* link address */
-	struct lowdown_buf text; /* shown address */
 	enum halink_type type; /* type of link */
 };
 
@@ -173,8 +174,10 @@ struct	rndr_raw_html {
 };
 
 struct	rndr_link {
-	struct lowdown_buf link; /* link address */
-	struct lowdown_buf title; /* title of link */
+	struct lowdown_buf link;
+	struct lowdown_buf title;
+	struct lowdown_buf attr_cls;
+	struct lowdown_buf attr_id;
 };
 
 struct	rndr_blockcode {
@@ -235,12 +238,14 @@ struct	rndr_header{
 };
 
 struct	rndr_image {
-	struct lowdown_buf link; /* image address */
-	struct lowdown_buf title; /* title of image */
-	struct lowdown_buf dims; /* NNxNN dimensions */
-	struct lowdown_buf alt; /* alt-text of image */
-	struct lowdown_buf attr_width; /* ext: width */
-	struct lowdown_buf attr_height; /* ext: height */
+	struct lowdown_buf link;
+	struct lowdown_buf title;
+	struct lowdown_buf dims;
+	struct lowdown_buf alt;
+	struct lowdown_buf attr_width;
+	struct lowdown_buf attr_height;
+	struct lowdown_buf attr_cls;
+	struct lowdown_buf attr_id;
 };
 
 struct rndr_math {
@@ -310,7 +315,9 @@ struct	lowdown_opts {
 #define	LOWDOWN_METADATA	  0x4000
 #define	LOWDOWN_COMMONMARK	  0x8000
 #define	LOWDOWN_DEFLIST		  0x10000
-#define	LOWDOWN_IMG_EXT	 	  0x20000
+#define	LOWDOWN_IMG_EXT	 	  0x20000 /* -> LOWDOWN_ATTRS */
+#define LOWDOWN_TASKLIST	  0x40000
+#define LOWDOWN_ATTRS		  0x80000
 	unsigned int		  oflags;
 #define LOWDOWN_HTML_SKIP_HTML	  0x01 /* skip all HTML */
 #define LOWDOWN_HTML_ESCAPE	  0x02 /* escape HTML (if not skip) */
@@ -326,7 +333,8 @@ struct	lowdown_opts {
 #define LOWDOWN_STANDALONE	  0x200 /* emit complete document */
 #define LOWDOWN_TERM_SHORTLINK	  0x400 /* shorten URLs */
 #define LOWDOWN_TERM_NOLINK	  0x20000 /* don't show URLs */
-#define	LOWDOWN_TERM_NOCOLOUR	  0x800000 /* no colours */
+#define	LOWDOWN_TERM_NOCOLOUR	  0x800000 /* no ANSI colours */
+#define	LOWDOWN_TERM_NOANSI	  0x1000000 /* no ANSI escapes at all */
 #define	LOWDOWN_HTML_OWASP	  0x800 /* use OWASP escaping */
 #define	LOWDOWN_HTML_NUM_ENT	  0x1000 /* use &#nn; if possible */
 #define LOWDOWN_LATEX_SKIP_HTML	  0x2000 /* skip all HTML */
@@ -356,11 +364,11 @@ int	 lowdown_buf(const struct lowdown_opts *,
 		char **, size_t *, struct lowdown_metaq *);
 int	 lowdown_buf_diff(const struct lowdown_opts *, 
 		const char *, size_t, const char *, size_t,
-		char **, size_t *, struct lowdown_metaq *);
+		char **, size_t *);
 int	 lowdown_file(const struct lowdown_opts *, 
 		FILE *, char **, size_t *, struct lowdown_metaq *);
 int	 lowdown_file_diff(const struct lowdown_opts *, FILE *, 
-		FILE *, char **, size_t *, struct lowdown_metaq *);
+		FILE *, char **, size_t *);
 
 /* 
  * Low-level functions.
@@ -375,8 +383,8 @@ void	 lowdown_buf_free(struct lowdown_buf *);
 struct lowdown_doc
 	*lowdown_doc_new(const struct lowdown_opts *);
 struct lowdown_node
-	*lowdown_doc_parse(struct lowdown_doc *,
-		size_t *, const char *, size_t);
+	*lowdown_doc_parse(struct lowdown_doc *, size_t *,
+		const char *, size_t, struct lowdown_metaq *);
 struct lowdown_node
 	*lowdown_diff(const struct lowdown_node *,
 		const struct lowdown_node *, size_t *);
@@ -387,26 +395,22 @@ void 	 lowdown_node_free(struct lowdown_node *);
 
 void	 lowdown_html_free(void *);
 void	*lowdown_html_new(const struct lowdown_opts *);
-int 	 lowdown_html_rndr(struct lowdown_buf *,
-		struct lowdown_metaq *, void *, 
+int 	 lowdown_html_rndr(struct lowdown_buf *, void *, 
 		const struct lowdown_node *);
 
 void	 lowdown_gemini_free(void *);
 void	*lowdown_gemini_new(const struct lowdown_opts *);
-int 	 lowdown_gemini_rndr(struct lowdown_buf *,
-		struct lowdown_metaq *, void *, 
+int 	 lowdown_gemini_rndr(struct lowdown_buf *, void *, 
 		const struct lowdown_node *);
 
 void	 lowdown_term_free(void *);
 void	*lowdown_term_new(const struct lowdown_opts *);
-int 	 lowdown_term_rndr(struct lowdown_buf *,
-		struct lowdown_metaq *, void *, 
+int 	 lowdown_term_rndr(struct lowdown_buf *, void *, 
 		const struct lowdown_node *);
 
 void	 lowdown_nroff_free(void *);
 void	*lowdown_nroff_new(const struct lowdown_opts *);
-int 	 lowdown_nroff_rndr(struct lowdown_buf *, 
-		struct lowdown_metaq *, void *, 
+int 	 lowdown_nroff_rndr(struct lowdown_buf *, void *, 
 		const struct lowdown_node *);
 
 int 	 lowdown_tree_rndr(struct lowdown_buf *, 
@@ -414,8 +418,7 @@ int 	 lowdown_tree_rndr(struct lowdown_buf *,
 
 void	 lowdown_latex_free(void *);
 void	*lowdown_latex_new(const struct lowdown_opts *);
-int 	 lowdown_latex_rndr(struct lowdown_buf *, 
-		struct lowdown_metaq *, void *, 
+int 	 lowdown_latex_rndr(struct lowdown_buf *, void *, 
 		const struct lowdown_node *);
 
 __END_DECLS
